set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_Table9, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces Table 9 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.

*/

clear 
set mem 10g
set matsize 10000

use ../Data/aggregsdata, clear

tsset, clear

*Country 1 effects

qui tab ifscode1, ge(_Iifs1)

areg corr_growth_gdp lbitrade_gdp _Iifs1*,r abs(ifscode2)

sum lbitrade_gdp if e(sample), d

matrix define deltaT = r(p75)-r(p25)

********************************************************************************
* OECD-OECD sample
********************************************************************************

use ../Data/indx_data_corrij_final, clear
do oecd_dummy
keep if oecd1==1 & oecd2==1

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

svmat deltaT
egen deltaT = mean(deltaT1)

ge obj1_sig_nio= share1*share2*vol1*vol2/(vol_agg1*vol_agg2)
ge obj1_sig_io= share1*share2*vol1*vol2/(vol_agg1*vol_agg2)*(IO_USA1+IO_USA2)
egen sobj1_sig_nio = sum(obj1_sig_nio), by(pid_ifs)
egen sobj1_sig_io = sum(obj1_sig_io), by(pid_ifs)

gen ltrade = lbiexports_gdp1+lbiexports_gdp2
ge ltrade_io = IO_USA1*lbiexports_gdp1+IO_USA2*lbiexports_gdp2

xi: areg corr ltrade ltrade_io i.pid_ifs, abs(pid_isic) robust

mat b3 = e(b)
mat v3 = e(V)

ge delta_rhoagg_nio = sobj1_sig_nio*(b3[1,1])*deltaT*2
ge delta_rhoagg_io = sobj1_sig_io*(b3[1,2])*deltaT

ge delta_rhoagg_nio_se = sobj1_sig_nio*sqrt(v3[1,1])*deltaT*2
ge delta_rhoagg_io_se = sobj1_sig_io*sqrt(v3[2,2])*deltaT

ge delta_rhoagg_comb_nio_io = delta_rhoagg_io + delta_rhoagg_nio

ge delta_rhoagg_comb_nio_io_se = sqrt(((sobj1_sig_nio*deltaT*2)^2)*v3[1,1] + ((sobj1_sig_io*deltaT)^2)*v3[2,2] + 2*sobj1_sig_nio*deltaT*2*sobj1_sig_io*deltaT*v3[1,2])

save oo_magfile_ltrade, replace

use oo_magfile_ltrade, clear
drop if delta_rhoagg_nio==0
egen sectorpairs = count(delta_rhoagg_nio), by(pid_ifs)
drop if sectorpairs<400
sort pid_ifs

gen table_three = 1

* Columns 2 and 3
table table_three if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_nio mean delta_rhoagg_nio mean delta_rhoagg_nio_se mean delta_rhoagg_io mean delta_rhoagg_io_se) 
* Column 1
table table_three if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_comb_nio_io mean delta_rhoagg_comb_nio_io mean delta_rhoagg_comb_nio_io_se) 

gen sharevert = delta_rhoagg_io/delta_rhoagg_comb_nio_io
sum sharevert if pid_ifs~=pid_ifs[_n-1], d

erase oo_magfile_ltrade.dta

********************************************************************************
* OECD-non-OECD sample
********************************************************************************

use ../Data/indx_data_corrij_final, clear
do oecd_dummy
keep if (oecd1==1 & oecd2==0) | (oecd1==0 & oecd2==1)

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

svmat deltaT
egen deltaT = mean(deltaT1)

ge obj1_sig_nio= share1*share2*vol1*vol2/(vol_agg1*vol_agg2)
ge obj1_sig_io= share1*share2*vol1*vol2/(vol_agg1*vol_agg2)*(IO_USA1+IO_USA2)
egen sobj1_sig_nio = sum(obj1_sig_nio), by(pid_ifs)
egen sobj1_sig_io = sum(obj1_sig_io), by(pid_ifs)

gen ltrade = lbiexports_gdp1+lbiexports_gdp2
ge ltrade_io = IO_USA1*lbiexports_gdp1+IO_USA2*lbiexports_gdp2

xi: areg corr ltrade ltrade_io i.pid_ifs, abs(pid_isic) robust

mat b3 = e(b)
mat v3 = e(V)

ge delta_rhoagg_nio = sobj1_sig_nio*(b3[1,1])*deltaT*2
ge delta_rhoagg_io = sobj1_sig_io*(b3[1,2])*deltaT

ge delta_rhoagg_nio_se = sobj1_sig_nio*sqrt(v3[1,1])*deltaT*2
ge delta_rhoagg_io_se = sobj1_sig_io*sqrt(v3[2,2])*deltaT

ge delta_rhoagg_comb_nio_io = delta_rhoagg_io + delta_rhoagg_nio

ge delta_rhoagg_comb_nio_io_se = sqrt(((sobj1_sig_nio*deltaT*2)^2)*v3[1,1] + ((sobj1_sig_io*deltaT)^2)*v3[2,2] + 2*sobj1_sig_nio*deltaT*2*sobj1_sig_io*deltaT*v3[1,2])

save on_magfile_ltrade, replace

use on_magfile_ltrade, clear
drop if delta_rhoagg_nio==0
egen sectorpairs = count(delta_rhoagg_nio), by(pid_ifs)
drop if sectorpairs<400
sort pid_ifs

gen table_three = 1

* Columns 2 and 3
table table_three if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_nio mean delta_rhoagg_nio mean delta_rhoagg_nio_se mean delta_rhoagg_io mean delta_rhoagg_io_se) 
* Column 1
table table_three if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_comb_nio_io mean delta_rhoagg_comb_nio_io mean delta_rhoagg_comb_nio_io_se) 

gen sharevert = delta_rhoagg_io/delta_rhoagg_comb_nio_io
sum sharevert if pid_ifs~=pid_ifs[_n-1], d

erase on_magfile_ltrade.dta

********************************************************************************
* non-OECD-non-OECD sample
********************************************************************************

use ../Data/indx_data_corrij_final, clear
do oecd_dummy
keep if oecd1==0 & oecd2==0
* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

svmat deltaT
egen deltaT = mean(deltaT1)

ge obj1_sig_nio= share1*share2*vol1*vol2/(vol_agg1*vol_agg2)
ge obj1_sig_io= share1*share2*vol1*vol2/(vol_agg1*vol_agg2)*(IO_USA1+IO_USA2)
egen sobj1_sig_nio = sum(obj1_sig_nio), by(pid_ifs)
egen sobj1_sig_io = sum(obj1_sig_io), by(pid_ifs)

gen ltrade = lbiexports_gdp1+lbiexports_gdp2
ge ltrade_io = IO_USA1*lbiexports_gdp1+IO_USA2*lbiexports_gdp2

xi: areg corr ltrade ltrade_io i.pid_ifs, abs(pid_isic) robust

mat b3 = e(b)
mat v3 = e(V)

ge delta_rhoagg_nio = sobj1_sig_nio*(b3[1,1])*deltaT*2
ge delta_rhoagg_io = sobj1_sig_io*(b3[1,2])*deltaT

ge delta_rhoagg_nio_se = sobj1_sig_nio*sqrt(v3[1,1])*deltaT*2
ge delta_rhoagg_io_se = sobj1_sig_io*sqrt(v3[2,2])*deltaT

ge delta_rhoagg_comb_nio_io = delta_rhoagg_io + delta_rhoagg_nio

ge delta_rhoagg_comb_nio_io_se = sqrt(((sobj1_sig_nio*deltaT*2)^2)*v3[1,1] + ((sobj1_sig_io*deltaT)^2)*v3[2,2] + 2*sobj1_sig_nio*deltaT*2*sobj1_sig_io*deltaT*v3[1,2])

save nn_magfile_ltrade, replace

use nn_magfile_ltrade, clear
drop if delta_rhoagg_nio==0
egen sectorpairs = count(delta_rhoagg_nio), by(pid_ifs)
drop if sectorpairs<400
sort pid_ifs

gen table_three = 1

* Columns 2 and 3
table table_three if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_nio mean delta_rhoagg_nio mean delta_rhoagg_nio_se mean delta_rhoagg_io mean delta_rhoagg_io_se) 
* Column 1
table table_three if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_comb_nio_io mean delta_rhoagg_comb_nio_io mean delta_rhoagg_comb_nio_io_se) 

gen sharevert = delta_rhoagg_io/delta_rhoagg_comb_nio_io
sum sharevert if pid_ifs~=pid_ifs[_n-1], d

erase nn_magfile_ltrade.dta

log close
