set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_Tables6_7, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces Tables 6-7 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.

*/

clear 
set mem 10g
set matsize 10000

use ..\data\aggregsdata

*Country 1 effects

qui tab ifscode1, ge(_Iifs1)

areg corr_growth_gdp lbitrade_gdp _Iifs1*,r abs(ifscode2)

sum lbitrade_gdp if e(sample), d

matrix define deltaT = r(p75)-r(p25)

use ..\Data\indx_data_corrij_final, clear

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

* Note: cs1 = u_1*d_i, cs2 = u_2*d_j

svmat deltaT
egen deltaT = mean(deltaT1)

**********************************************************
* Exercise 1: the pooled regression, same coefficient
**********************************************************

gen ltrade = lbiexports_gdp1+lbiexports_gdp2
xi: areg corr_12 ltrade i.pid_ifs, abs(pid_isic) robust

mat b1 = e(b)
mat v1 = e(V)

ge obj1=share1*share2*vol1*vol2/(vol_agg1*vol_agg2)
egen sobj1 = sum(obj1), by(pid_ifs)

gen delta_rho_agg = 2*sobj1*b1[1,1]*deltaT
gen delta_rho_agg_se = 2*sobj1*sqrt(v1[1,1])*deltaT

sum delta_rho_agg* if e(sample), d

**********************************************************
* Exercise 2: the pooled regression, different ii coefficient
**********************************************************

ge dsec=1-ssec
ge obj1_sig_ss = share1*share2*vol1*vol2*ssec/(vol_agg1*vol_agg2)
ge obj1_sig_ds = share1*share2*vol1*vol2*dsec/(vol_agg1*vol_agg2)
egen sobj1_sig_ss = sum(obj1_sig_ss), by(pid_ifs)
egen sobj1_sig_ds = sum(obj1_sig_ds), by(pid_ifs)

ge ss_ltrade=ssec*ltrade
ge ds_ltrade=dsec*ltrade
xi: areg corr ds_ltrade ss_ltrade i.pid_ifs, abs(pid_isic) robust

mat b2 = e(b)
mat v2 = e(V)

ge delta_rhoagg_ss = sobj1_sig_ss*(b2[1,2])*deltaT*2
ge delta_rhoagg_ds = sobj1_sig_ds*(b2[1,1])*deltaT*2

ge delta_rhoagg_ss_se = sobj1_sig_ss*sqrt(v2[2,2])*deltaT*2
ge delta_rhoagg_ds_se = sobj1_sig_ds*sqrt(v2[1,1])*deltaT*2

ge delta_rhoagg_comb_ds_ss = delta_rhoagg_ds + delta_rhoagg_ss 
ge delta_rhoagg_comb_ds_ss_se = sqrt(((sobj1_sig_ds*deltaT*2)^2)*v2[1,1] + ((sobj1_sig_ss*deltaT*2)^2)*v2[2,2] + 2*sobj1_sig_ss*deltaT*2*sobj1_sig_ds*deltaT*2*v2[1,2])

**********************************************************
* Exercise 3: separating main, IO coefficients
**********************************************************

ge obj1_sig_nio= share1*share2*vol1*vol2/(vol_agg1*vol_agg2)
ge obj1_sig_io= share1*share2*vol1*vol2/(vol_agg1*vol_agg2)*(IO_USA1+IO_USA2)
egen sobj1_sig_nio = sum(obj1_sig_nio), by(pid_ifs)
egen sobj1_sig_io = sum(obj1_sig_io), by(pid_ifs)

ge ltrade_io = IO_USA1*lbiexports_gdp1+IO_USA2*lbiexports_gdp2

xi: areg corr ltrade ltrade_io i.pid_ifs, abs(pid_isic) robust

mat b3 = e(b)
mat v3 = e(V)

ge delta_rhoagg_nio = sobj1_sig_nio*(b3[1,1])*deltaT*2
ge delta_rhoagg_io = sobj1_sig_io*(b3[1,2])*deltaT

ge delta_rhoagg_nio_se = sobj1_sig_nio*sqrt(v3[1,1])*deltaT*2
ge delta_rhoagg_io_se = sobj1_sig_io*sqrt(v3[2,2])*deltaT

ge delta_rhoagg_comb_nio_io = delta_rhoagg_io + delta_rhoagg_nio

ge delta_rhoagg_comb_nio_io_se = sqrt(((sobj1_sig_nio*deltaT*2)^2)*v3[1,1] + ((sobj1_sig_io*deltaT)^2)*v3[2,2] + 2*sobj1_sig_nio*deltaT*2*sobj1_sig_io*deltaT*v3[1,2])

***********************************************************************
* Exercise 4: separating main, IO coefficients; ii and ij separately
***********************************************************************

ge obj1_sig_nio_ss = share1*share2*vol1*vol2*ssec/(vol_agg1*vol_agg2)
ge obj1_sig_nio_ds = share1*share2*vol1*vol2*dsec/(vol_agg1*vol_agg2)
ge obj1_sig_io_ss = share1*share2*vol1*vol2*ssec/(vol_agg1*vol_agg2)*(IO_USA1+IO_USA2)
ge obj1_sig_io_ds = share1*share2*vol1*vol2*dsec/(vol_agg1*vol_agg2)*(IO_USA1+IO_USA2)

egen sobj1_sig_nio_ss = sum(obj1_sig_nio_ss), by(pid_ifs)
egen sobj1_sig_io_ss = sum(obj1_sig_io_ss), by(pid_ifs)
egen sobj1_sig_nio_ds = sum(obj1_sig_nio_ds), by(pid_ifs)
egen sobj1_sig_io_ds = sum(obj1_sig_io_ds), by(pid_ifs)

ge ss_ltrade_io = ssec*ltrade_io
ge ds_ltrade_io = dsec*ltrade_io

xi: areg corr ds_ltrade ss_ltrade ds_ltrade_io ss_ltrade_io i.pid_ifs, abs(pid_isic) robust

mat b4 = e(b)
mat v4 = e(V)

ge delta_rhoagg_nio_ds = sobj1_sig_nio_ds*(b4[1,1])*deltaT*2
ge delta_rhoagg_nio_ss = sobj1_sig_nio_ss*(b4[1,2])*deltaT*2
ge delta_rhoagg_io_ds = sobj1_sig_io_ds*(b4[1,3])*deltaT
ge delta_rhoagg_io_ss = sobj1_sig_io_ss*(b4[1,4])*deltaT

ge delta_rhoagg_nio_ds_se = sobj1_sig_nio_ds*sqrt(v4[1,1])*deltaT*2
ge delta_rhoagg_nio_ss_se = sobj1_sig_nio_ss*sqrt(v4[2,2])*deltaT*2
ge delta_rhoagg_io_ds_se = sobj1_sig_io_ds*sqrt(v4[3,3])*deltaT
ge delta_rhoagg_io_ss_se = sobj1_sig_io_ss*sqrt(v4[4,4])*deltaT

ge delta_rhoagg_comb_master = delta_rhoagg_nio_ds + delta_rhoagg_nio_ss + delta_rhoagg_io_ds + delta_rhoagg_io_ss

ge a = sobj1_sig_nio_ds*deltaT*2
ge b = sobj1_sig_nio_ss*deltaT*2
ge c = sobj1_sig_io_ds*deltaT
ge d = sobj1_sig_io_ss*deltaT

#delimit ;

ge var = a^2*v4[1,1] + b^2*v4[2,2] + c^2*v4[3,3] + d^2*v4[4,4] +
        2*a*b*v4[2,1] + 2*a*c*v4[3,1] + 2*a*d*v4[4,1] +
        2*b*c*v4[3,2] + 2*b*d*v4[4,2] +
        2*c*d*v4[4,3];
#delimit cr

ge delta_rhoagg_comb_master_se = sqrt(var)
save magfile_ltrade, replace

use magfile_ltrade, clear
drop if delta_rho_agg==0
egen sectorpairs = count(delta_rho_agg), by(pid_ifs)
drop if sectorpairs<400
sort pid_ifs

* Table 6 Top Panel: change given specification 1 (only trade)

gen table_one = 1
table table_one if pid_ifs~=pid_ifs[_n-1], c(n delta_rho_agg mean delta_rho_agg mean  delta_rho_agg_se )

sum delta_rho_agg if pid_ifs~=pid_ifs[_n-1], d

* Table 6 Bottom Panel: change given specification 2 (trade within and cross sectors)

gen table_two = 1
table table_two if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_ss mean delta_rhoagg_ss mean delta_rhoagg_ss_se mean delta_rhoagg_ds mean delta_rhoagg_ds_se) 
table table_two if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_comb_ds_ss mean delta_rhoagg_comb_ds_ss mean delta_rhoagg_comb_ds_ss_se) 

* Table 7 Top Panel: change given specification 3 (trade interacted with input-output)

gen table_three = 1
table table_three if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_nio mean delta_rhoagg_nio mean delta_rhoagg_nio_se mean delta_rhoagg_io mean delta_rhoagg_io_se) 
table table_three if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_comb_nio_io mean delta_rhoagg_comb_nio_io mean delta_rhoagg_comb_nio_io_se) 

gen sharevert = delta_rhoagg_io/delta_rhoagg_comb_nio_io
sum sharevert if pid_ifs~=pid_ifs[_n-1], d

* Table 7 Bottom Panel: change given specification 4 (trade interacted with input-output within and cross sectors)

gen table_four = 1
table table_four if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_nio_ds mean delta_rhoagg_nio_ds mean delta_rhoagg_nio_ds_se mean delta_rhoagg_nio_ss mean delta_rhoagg_nio_ss_se) 
table table_four if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_io_ds mean delta_rhoagg_io_ds mean delta_rhoagg_io_ds_se mean delta_rhoagg_io_ss mean delta_rhoagg_io_ss_se)
table table_four if pid_ifs~=pid_ifs[_n-1], c(n delta_rhoagg_comb_master mean delta_rhoagg_comb_master mean delta_rhoagg_comb_master_se) 

* Histogram of change in aggregate correlation across all country pairs

hist delta_rho_agg if pid_ifs~=pid_ifs[_n-1], bin(50) xtitle("Change in Aggregate Bilateral Correlation") saving(indx_hist_dCorr_ltrade, replace)
graph export indx_hist_dCorr_ltrade.eps, replace

erase magfile_ltrade.dta
log close
