set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_TablesB2_3, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces Tables B2 and B3 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.
 */

clear

set mem 12g
set matsize 10000

use ../Data/indx_data_corrij_final

tsset, clear

* Keep correlations with observations greater than 9 in calculations.

keep if obs_12>9

* Create country and sector pair codes

ge pid_ifs = ifscode1*1000+ifscode2

ge pid_isic = isiccode1*1000+isiccode2 if isiccode1<=isiccode2
replace pid_isic = isiccode1+isiccode2*1000 if isiccode1>isiccode2

ge ssec = 0
replace ssec = 1 if isiccode1 == isiccode2

ge trade = biexports_gdp1+biexports_gdp2
ge ltrade = ln(biexports_gdp1)+ln(biexports_gdp2)

* Generate pctiles for trade ratio

local i = 1
foreach X of numlist .5 1.25 2.5 5 95 97.5 98.75 99.5{
    egen trade_p`i' = pctile(trade), p(`X')
    egen trade_nz_p`i' = pctile(trade) if ltrade~=., p(`X')
    egen ltrade_p`i' = pctile(ltrade), p(`X')
    local i = `i'+1
}   

* Regressions

* Table B2: levels trimming

xi: areg corr trade i.pid_isic, abs(pid_ifs) r
outreg trade using tableB2, replace se 10pct nolab bdec(4) rdec(3) coef

foreach X of numlist 1/4{
    local Y = 8-`X'+1
    areg corr trade _I* if trade>trade_p`X' & trade<trade_p`Y', abs(pid_ifs) r
    outreg trade using tableB2, append se 10pct nolab bdec(4) rdec(3) coef
}

* Table B3: log trimming

areg corr ltrade _I*, abs(pid_ifs) r
outreg ltrade using tableB3, replace se 10pct nolab bdec(4) rdec(3) coef

foreach X of numlist 1/4{
    local Y = 8-`X'+1
    areg corr ltrade _I* if ltrade>ltrade_p`X' & ltrade<ltrade_p`Y', abs(pid_ifs) r
    outreg ltrade using tableB3, append se 10pct nolab bdec(4) rdec(3) coef
}

log close 
